﻿using Syncfusion.SfCalendar.XForms;
using System;
using System.Collections.Generic;
using System.Text;
using Xamarin.Forms;

namespace MonthCellTemplate
{
    class CalendarBehavior : Behavior<ContentPage>
    {
        SfCalendar calendar;
        public CalendarEventCollection CalendarInlineEvents { get; set; } = new CalendarEventCollection();
        protected override void OnAttachedTo(ContentPage bindable)
        {
            base.OnAttachedTo(bindable);
            calendar = bindable.FindByName<SfCalendar>("calendar");

            CalendarInlineEvent event1 = new CalendarInlineEvent();
            var dateTime = DateTime.Now.AddDays(1);
            event1.StartTime = new DateTime(dateTime.Year, dateTime.Month, dateTime.Day, 5, 0, 0);
            event1.EndTime = new DateTime(dateTime.Year, dateTime.Month, dateTime.Day, 7, 0, 0);
            event1.Subject = "Go to Meeting";
            event1.Color = Color.Fuchsia;

            dateTime = dateTime.AddDays(1);
            CalendarInlineEvent event2 = new CalendarInlineEvent();
            event2.StartTime = new DateTime(dateTime.Year, dateTime.Month, dateTime.Day, 10, 0, 0);
            event2.EndTime = new DateTime(dateTime.Year, dateTime.Month, dateTime.Day, 12, 0, 0);
            event2.Subject = "Planning";
            event2.Color = Color.Green;

            CalendarInlineEvents.Add(event1);
            CalendarInlineEvents.Add(event2);
            calendar.DataSource = CalendarInlineEvents;
            calendar.OnMonthCellLoaded += Calendar_OnMonthCellLoaded;
        }

        private void Calendar_OnMonthCellLoaded(object sender, MonthCellLoadedEventArgs e)
        {
            var dataTemplate = GetDayModelFor(e.Date, calendar);
            e.CellBindingContext = dataTemplate;

        }

        public CalendarViewModel GetDayModelFor(DateTime date, SfCalendar calendar)
        {
            var selectedDate = (DateTime)calendar.SelectedDate;
            var isEventedDate = false;
            if (calendar.DataSource != null && calendar.DataSource.Count > 0)
            {
                for (int i = 0; i < calendar.DataSource.Count; i++)
                {
                    if (calendar.DataSource[i].StartTime.Date == date.Date || calendar.DataSource[i].EndTime.Date == date.Date)
                    {
                        isEventedDate = true;
                        break;
                    }
                }
            }

            var selected = calendar.SelectedDate != null && date.Month == selectedDate.Month &&
                                     date.Year == selectedDate.Year && date.Day == selectedDate.Day;
            return new CalendarViewModel()
            {
                Calendar = calendar,
                Date = date.Date,
                HasEvents = isEventedDate,
                IsToday = date.Day == DateTime.Today.Day &&
                              date.Month == DateTime.Today.Month &&
                              date.Year == DateTime.Today.Year,
                IsSelected = selected,
                SelectedTextColor = selected ? Color.White : Color.Red,
                SelectedBgColor = selected ? Color.DarkGreen : isEventedDate ? Color.CornflowerBlue : Color.White
            };
        }
    }
}
    
